@@ -1,5 +1,5 @@
 package App::vaporcalc;
-$App::vaporcalc::VERSION = '0.001004';
+$App::vaporcalc::VERSION = '0.002001';
 use Defaults::Modern;
 
 use App::vaporcalc::Recipe;
@@ -68,8 +68,11 @@ L<App::vaporcalc::Recipe> directly).
     target_pg         => 65,   # target PG percentage
     target_vg         => 35,   # target VG percentage
 
-    flavor_percentage => 15,   # target flavor percentage
-    flavor_type       => 'PG', # flavor base type (VG/PG, default PG)
+    # target flavor(s) name, percentage, base type:
+    flavor_array => [
+      +{ tag => 'Raspberry', percentage => 15, type => 'PG' },
+      # ...
+    ],
   );
 
   # Returns an App::vaporcalc::RecipeResultSet ->
@@ -88,23 +91,27 @@ L<App::vaporcalc::Result>
 
 L<App::vaporcalc::RecipeResultSet>
 
+L<App::vaporcalc::Flavor>
+
 =head1 TIPS
 
 Less is more with many flavors; you may want to start around 5% or so and work
 your way up.
 
-Ideally, let juices steep for at least a day before sampling; shaking and
-warmth can help steep flavors faster.
+Ideally, let juices steep for at least a day (longer is usually better!)
+before sampling; shaking and warmth can help steep flavors faster.
 
 Don't use flavors containing diacetyl (frequently used to create a buttery
-taste). It's safe to eat, not safe to vape.
+taste). It's safe to eat, not safe to vape; the vapor causes "popcorn lung."
+Acetoin will ferment into diacetyl; avoid that for the same reasons.
 
 Anything containing artifical coloring or triglycerides is possibly not safe
 to vape.
 
 Flavors containing triacetin are reported to cause cracking in various plastic
 tanks. Triacetin is a reasonable flavor carrier and probably OK to vape, but
-may be rough on equipment.
+may be rough on equipment. Same goes for citric acid -- and it may break down
+into lung/throat irritants upon heating.
 
 Buy nicotine from a reputable supplier and test it; there have been instances
 of nicotine solutions marketed as 100mg/ml going as high as 250mg/ml!
