@@ -1,5 +1,5 @@
 package App::vaporcalc::FormatString;
-$App::vaporcalc::FormatString::VERSION = '0.001004';
+$App::vaporcalc::FormatString::VERSION = '0.002001';
 use Defaults::Modern;
 
 use parent 'Exporter::Tiny';
@@ -23,7 +23,7 @@ sub format_str {
     $orig
   };
 
-  my $re = qr/(%([^\s%]+)%?)/;
+  state $re = qr/(%([^\s%]+)%?)/;
   $string =~ s/$re/$rpl->($1, $2)/ge;
 
   $string
