@@ -1,6 +1,7 @@
 package App::vaporcalc::Role::Calc;
-$App::vaporcalc::Role::Calc::VERSION = '0.001004';
-use Defaults::Modern;
+$App::vaporcalc::Role::Calc::VERSION = '0.002001';
+use Defaults::Modern
+  -with_types => [ 'App::vaporcalc::Types' ];
 
 use App::vaporcalc::Result;
 
@@ -13,8 +14,7 @@ requires qw/
   target_nic_per_ml
   target_pg
   target_vg
-  flavor_percentage
-  flavor_type
+  flavor_array
 /;
 
 method _base_multiplier { 100 / ($self->base_nic_per_ml || return 1) }
@@ -36,15 +36,28 @@ method _calc_total_pg_qty {
   $self->target_quantity * ($self->target_pg / 100)
 }
 
-method _calc_total_flavor_qty {
-  return 0 unless $self->flavor_percentage;
-  $self->target_quantity * ($self->flavor_percentage / 100)
+method _calc_per_flavor_qty_obj {
+  my $res = hash_of Object;
+
+  for my $flav ($self->flavor_array->all) {
+    my $pcnt = $flav->percentage || next;
+    my $ml = $self->target_quantity * ($pcnt / 100);
+    $res->set(
+      $flav->tag => hash(ml => $ml, type => $flav->type)->inflate
+    );
+  }
+
+  # hash( $name => $obj );
+  #   $obj->ml, $obj->type
+  $res
 }
 
 method calc {
   my $vg_ml     = $self->_calc_total_vg_qty;
   my $pg_ml     = $self->_calc_total_pg_qty;
-  my $flavor_ml = $self->_calc_total_flavor_qty;
+
+  my $flavor_data = $self->_calc_per_flavor_qty_obj;
+
   my $nic_base_ml = $self->_calc_base_nic_qty;
 
   # Subtract our nic base total from the appropriate PG or VG total:
@@ -54,19 +67,29 @@ method calc {
     default: { confess "Unknown base_nic_type", $self->base_nic_type }
   }
 
-  # Same for flavor:
-  sswitch ($self->flavor_type) {
-    case 'PG': { $pg_ml -= $flavor_ml if $pg_ml }
-    case 'VG': { $vg_ml -= $flavor_ml if $vg_ml }
-    default: { confess "Unknown flavor_type ", $self->flavor_type }
+  # Same for flavors:
+  for my $fname ($flavor_data->keys->all) {
+    my $fobj  = $flavor_data->get($fname);
+    my $ftype = $fobj->type;
+    my $fml   = $fobj->ml;    # no, srsly
+    sswitch ($ftype) {
+      case 'PG': { $pg_ml -= $fml if $pg_ml }
+      case 'VG': { $vg_ml -= $fml if $vg_ml }
+      default: { confess "Unknown flavor_type ", $self->flavor_type }
+    }
   }
 
+  my $flavors = hash_of RoundedResult() => (
+    map {; $_ => sprintf '%.1f', $flavor_data->get($_)->ml }
+      $flavor_data->keys->all
+  );
+
   App::vaporcalc::Result->new(
     vg  => sprintf('%.1f', $vg_ml),
     pg  => sprintf('%.1f', $pg_ml),
     nic => sprintf('%.1f', $nic_base_ml),
-    flavor => sprintf('%.1f', $flavor_ml),
-    total  => $self->target_quantity,
+    flavors => $flavors,
+    total   => $self->target_quantity,
   )
 }
 
@@ -102,8 +125,7 @@ Consumers need to implement the following methods:
   target_nic_per_ml  (mg/ml)
   target_pg          (percentage)
   target_vg          (percentage)
-  flavor_type        ('PG' or 'VG')
-  flavor_percentage  (percentage)
+  flavor_array       (an array of App::vaporcalc::Flavor objects)
 
 =head2 METHODS
 
