@@ -1,9 +1,11 @@
 package App::vaporcalc::Role::UI::ParseCmd;
-$App::vaporcalc::Role::UI::ParseCmd::VERSION = '0.001004';
+$App::vaporcalc::Role::UI::ParseCmd::VERSION = '0.002001';
 use Defaults::Modern;
 
 use App::vaporcalc::Exception;
 
+use Text::ParseWords;
+
 use Role::Tiny;
 requires 'subject_list';
 
@@ -15,7 +17,23 @@ method parse_cmd (Str $str) {
   my ($subj, $verb);
   my $params = array;
 
-  SUBJ: for my $maybe (@{ $self->subject_list }) {
+  # FIXME
+  #  alternate approach to find first subj in line:
+  #    split line into words and pairs ARRAY
+  #      > notes add Flavor too strong
+  #      # [ 'notes', 'notes add', 'add', 'add Flavor', 'Flavor', .. ]
+  #    walk for first valid subj
+  #      die if none
+  #    remove subj and pairs from ARRAY
+  #      # [ 'add', 'Flavor', .. ]
+  #    remainder is $pieces
+  #    verb is $pieces->shift
+  #   test for same
+  my @subjs = array(@{ $self->subject_list })
+    ->nsort_by(sub { length })
+    ->reverse
+    ->all;
+  SUBJ: for my $maybe (@subjs) {
     my $idx = index $str, $maybe;
     next SUBJ if $idx == -1;
     no warnings 'substr';
@@ -31,7 +49,9 @@ method parse_cmd (Str $str) {
     substr $str, $idx, length($maybe), ' ';
     my $pieces = array( split ' ', $str );
     $verb = $pieces->shift;
-    $params = $pieces;
+    $params = array( 
+      Text::ParseWords::parse_line('\s+', 0, $pieces->join(' '))
+    );
     last SUBJ
   }
 
