@@ -1,7 +1,9 @@
 package App::vaporcalc::Types;
-$App::vaporcalc::Types::VERSION = '0.001004';
+$App::vaporcalc::Types::VERSION = '0.002001';
 use strict; use warnings FATAL => 'all';
 
+use match::simple;
+
 use Type::Library   -base;
 use Types::Standard -types;
 use Type::Utils     -all;
@@ -57,6 +59,17 @@ coerce ResultObject =>
   };
 
 
+declare FlavorObject =>
+  as InstanceOf['App::vaporcalc::Flavor'];
+
+coerce FlavorObject =>
+  from HashRef(),
+  via {
+    require App::vaporcalc::Flavor;
+    App::vaporcalc::Flavor->new(%$_)
+  };
+
+
 declare RecipeResultSet =>
   as InstanceOf['App::vaporcalc::RecipeResultSet'];
 
@@ -71,6 +84,22 @@ coerce VaporLiquid =>
   via { uc $_ };
 
 
+declare CommandAction =>
+  as Str(),
+  where {
+    $_ |M| [qw/
+      display
+
+      print
+      prompt
+
+      next
+      last
+
+      recipe
+    /]
+  };
+
 1;
 
 =pod
@@ -107,6 +136,12 @@ An L<App::vaporcalc::Exception> instance.
 
 Can be coerced from a C<Str>.
 
+=head3 FlavorObject
+
+An L<App::vaporcalc::Flavor> instance.
+
+Can be coerced from a C<HashRef>.
+
 =head3 RecipeObject
 
 An L<App::vaporcalc::Recipe> instance.
@@ -131,6 +166,12 @@ A valid base liquid type (B<PG> or B<VG>).
 
 Can be coerced from a lowercase string.
 
+=head3 CommandAction
+
+A valid C<vaporcalc> loop control action, one of:
+
+  display print prompt next last recipe
+
 =head1 AUTHOR
 
 Jon Portnoy <avenj@cobaltirc.org>
